@@ -1,4 +1,17 @@
 # -*- coding: utf-8 -*-
+# Copyright (C) 2020 Red Hat, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 #
 # openstackdocstheme documentation build configuration file
 
@@ -22,7 +35,7 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-copyright = u'2015-2018, OpenStack Contributors'
+copyright = '2015-2018, OpenStack Contributors'
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
@@ -47,9 +60,7 @@ html_theme = 'openstackdocs'
 # variable, sidebar_dropdown, should be set to `api_ref`.
 # Otherwise, the list of links for the User and Ops docs
 # appear in the sidebar dropdown menu.
-html_theme_options = {
-    'show_other_versions': True
-}
+html_theme_options = {'show_other_versions': True}
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
@@ -63,7 +74,11 @@ html_static_path = ['_static/css']
 # (source start file, target name, title,
 #  author, documentclass [howto, manual, or own class]).
 latex_documents = [
-  ('index', 'doc-openstackdocstheme.tex',
-   u'OpenStack Docs Theme Documentation',
-   u'OpenStack Contributors', 'manual'),
+    (
+        'index',
+        'doc-openstackdocstheme.tex',
+        'OpenStack Docs Theme Documentation',
+        'OpenStack Contributors',
+        'manual',
+    ),
 ]
